#
# spec file for package python-oslo.service
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%if 0%{?rhel} || 0%{?fedora}
%global rdo 1
%endif
Name:           python-oslo.service
Version:        3.5.0
Release:        1.2
Summary:        OpenStack oslo.service library
License:        Apache-2.0
Group:          Development/Languages/Python
URL:            https://docs.openstack.org/oslo.service
Source0:        https://files.pythonhosted.org/packages/source/o/oslo.service/oslo.service-3.5.0.tar.gz
BuildRequires:  openstack-macros
BuildRequires:  procps
BuildRequires:  python3-Paste >= 2.0.2
BuildRequires:  python3-PasteDeploy >= 1.5.0
BuildRequires:  python3-Routes >= 2.3.1
BuildRequires:  python3-WebOb >= 1.7.1
BuildRequires:  python3-eventlet >= 0.25.2
BuildRequires:  python3-fixtures
BuildRequires:  python3-greenlet >= 0.4.15
BuildRequires:  python3-oslo.concurrency >= 3.25.0
BuildRequires:  python3-oslo.config >= 5.1.0
BuildRequires:  python3-oslo.i18n >= 3.15.3
BuildRequires:  python3-oslo.log >= 3.36.0
BuildRequires:  python3-oslo.utils >= 3.40.2
BuildRequires:  python3-oslotest
BuildRequires:  python3-pbr
BuildRequires:  python3-requests
BuildRequires:  python3-stestr
BuildRequires:  python3-yappi
BuildArch:      noarch

%description
oslo.service provides a framework for defining new long-running services using
the patterns established by other OpenStack applications. It also includes
utilities long-running applications might need for working with SSL or WSGI,
performing periodic operations, interacting with systemd, etc.

%package -n python3-oslo.service
Summary:        OpenStack oslo.service library
Requires:       python3-Paste >= 2.0.2
Requires:       python3-PasteDeploy >= 1.5.0
Requires:       python3-Routes >= 2.3.1
Requires:       python3-WebOb >= 1.7.1
Requires:       python3-debtcollector >= 1.2.0
Requires:       python3-eventlet >= 0.25.2
Requires:       python3-fixtures
Requires:       python3-greenlet >= 0.4.15
Requires:       python3-oslo.concurrency >= 3.25.0
Requires:       python3-oslo.config >= 5.1.0
Requires:       python3-oslo.i18n >= 3.15.3
Requires:       python3-oslo.log >= 3.36.0
Requires:       python3-oslo.utils >= 3.40.2
Requires:       python3-yappi

%description -n python3-oslo.service
oslo.service provides a framework for defining new long-running services using
the patterns established by other OpenStack applications. It also includes
utilities long-running applications might need for working with SSL or WSGI,
performing periodic operations, interacting with systemd, etc.

%package -n python-oslo.service-doc
Summary:        Documentation for OpenStack service library
BuildRequires:  python3-Sphinx
BuildRequires:  python3-openstackdocstheme

%description -n python-oslo.service-doc
oslo.service provides a framework for defining new long-running services using
the patterns established by other OpenStack applications. It also includes
utilities long-running applications might need for working with SSL or WSGI,
performing periodic operations, interacting with systemd, etc.
This package contains the documentation.

%prep
%autosetup -p1 -n oslo.service-3.5.0
%py_req_cleanup

%build
%{py3_build}

# generate html docs
PYTHONPATH=. PBR_VERSION=%{version} %sphinx_build -b html doc/source doc/build/html
# remove the sphinx-build leftovers
rm -rf doc/build/html/.{doctrees,buildinfo}

%install
%{py3_install}

%check
%{openstack_stestr_run}

%files -n python3-oslo.service
%license LICENSE
%doc README.rst ChangeLog
%{python3_sitelib}/oslo_service
%{python3_sitelib}/*.egg-info

%files -n python-oslo.service-doc
%license LICENSE
%doc doc/build/html

%changelog
* Tue Sep  3 2024 cloud-devel@suse.de
- update to version 3.5.0
  - Remove old excludes
  - reno: Update master for unmaintained/xena
  - Update master for stable/2024.1
  - reno: Update master for unmaintained/victoria
  - Update sslutils.wrap for newer Pythons
  - Make signal handling order predictable
  - reno: Update master for unmaintained/wallaby
  - reno: Update master for unmaintained/zed
* Sun Mar 24 2024 cloud-devel@suse.de
- update to version 3.4.0
  - Fix native threads on child process
  - pre-commit: Bump versions
  - pre-commit: Integrate doc8 and bandit
  - reno: Update master for unmaintained/yoga
  - Update master for stable/2023.2
  - Update python classifier in setup.cfg
  - Bump hacking
  - Switch to coverage command
* Thu Jan  4 2024 cloud-devel@suse.de
- update to version 3.2.0
  - Update master for stable/2023.1
  - Revert "Moves supported python runtimes from version 3.8 to 3.10"
  - Bump bandit
  - Imported Translations from Zanata
  - Moves supported python runtimes from version 3.8 to 3.10
* Mon Mar  6 2023 cloud-devel@suse.de
- update to version 3.1.1
  - Fix issues related to tox4
  - Add Python3 antelope unit tests
  - Fix misuse of assertTrue
  - Imported Translations from Zanata
  - Update master for stable/zed
* Thu Aug 11 2022 cloud-devel@suse.de
- update to version 3.0.0
  - Imported Translations from Zanata
  - Update master for stable/yoga
  - Add Python3 zed unit tests
  - Drop python3.6/3.7 support in testing runtime
* Tue May 24 2022 cloud-devel@suse.de
- update to version 2.8.0
  * Make debug option of wsgi server configurable
  * Fix fo() backdoor command for non-class objects
  * Fix BackOffLoopingCall error so it is not misleading
  * Add Python3 yoga unit tests
  * Update master for stable/xena
* Tue Oct 26 2021 cloud-devel@suse.de
- update to version 2.6.0
  - setup.cfg: Replace dashes with underscores
  - Add Python3 xena unit tests
  - remove unicode from code
  - Remove references to 'sys.version_info'
  - Remove lower-constraints remnants
  - Use TOX_CONSTRAINTS_FILE
  - Update master for stable/wallaby
  - Move flake8 as a pre-commit local target.
* Sun May  2 2021 cloud-devel@suse.de
- update to version 2.5.0
  - Use TOX_CONSTRAINTS_FILE
  - Add Python3 wallaby unit tests
  - Drop custom implementation of EVENTLET_HUB
  - Adding pre-commit
  - Update master for stable/victoria
  - Dropping lower constraints testing
  - Use py3 as the default runtime for tox
* Fri Oct  9 2020 cloud-devel@suse.de
- update to version 2.4.0
  - Do not import "oslo.log" in the main module
  - Fix some SSL tests for wsgi module under python 3
  - Stop to use the __future__ module.
  - Fix pygments style
  - Use unittest.mock instead of third party mock
  - Align contributing doc with oslo's policy
  - Raise minimum version of eventlet to 0.25.2
  - Fix wsgi/SSL/ipv6 tests for wsgi module under python 3
  - Add py38 package metadata
  - Remove the unused coding style modules
  - Remove translation sections from setup.cfg
  - Drop six usages
  - Add release notes links to doc index
  - Remove monotonic usage
  - Monkey patch original current_thread _active
  - Bump default tox env from py37 to py38
  - Fix wsgi SSL tests for wsgi module under python 3
  - Reactivate wsgi test related to socket option under python 3
  - Cleanup py27 support
  - [goal] Migrate testing to ubuntu focal
  - Align tests with monkey patch original current_thread _active
  - Update master for stable/ussuri
  - Add Python3 victoria unit tests
  - Switch to newer openstackdocstheme and reno versions
  - Fix hacking min version to 3.0.1
  - Bump bandit version
* Tue May 12 2020 cloud-devel@suse.de
- update to version 2.1.1
  - reword releasenote for py27 support dropping
  - remove outdated header
  - Add 'is_available' function
  - Update the constraints url
  - Update eventlet.
  - [ussuri][goal] Drop python 2.7 support and testing
  - Switch to official Ussuri jobs
  - Update master for stable/train
  - tox: Keeping going with docs
  - Extend test cert validity to 2049
  - Update hacking for Python3
  - Update the minversion parameter.
  - tox: Trivial cleanup
* Thu Mar 12 2020 Dirk Mueller <dmueller@suse.com>
- switch to python 3.x only client
* Wed Oct  9 2019 cloud-devel@suse.de
- update to version 1.40.2
  - Make PID availabe as formatstring in backdoor path
  - Polish usage.rst
  - Reno for SIGHUP fix
  - OpenDev Migration Patch
  - Dropping the py35 testing
  - Move doc related modules to doc/requirements.txt
  - Add workers' type check before launching the services
  - Add Python 3 Train unit tests
  - Cap Bandit below 1.6.0 and update Sphinx requirement
  - Replace git.openstack.org URLs with opendev.org URLs
  - Update master for stable/stein
  - restart: don't stop process on sighup when mutating
  - Stop using pbr to build docs
* Mon Apr  8 2019 cloud-devel@suse.de
- update to version 1.38.0
  - Bump oslo.utils lower constraint to 3.40.2
  - Add better timer APIs to ThreadGroup
  - Update mailinglist from dev to discuss
  - Use template for lower-constraints
  - Stop asserting on Eventlet internals
  - import zuul job settings from project-config
  - Use SleepFixture in looping call test suite
  - Always build universal wheels
  - Update reno for stable/rocky
  - Add stop_on_exception to TG timers
  - add python 3.6 unit test job
  - Avoid eventlet_backdoor listing on same port
  - Skips signal handling on Windows
  - add lib-forward-testing-python3 test job
  - Fix stop of loopingcall
  - Ensure connection is active in graceful shutdown tests
  - Deprecate the ThreadGroup.cancel() API
  - Use eventletutils Event class
  - Limit monotonic to py2
  - Update oslo.service to require yappi 1.0 or newer
  - Update hacking version
  - Fixture to mock loopingcall wait()
  - Clean up .gitignore references to personal tools
  - Use eventlet Event for loopingcall events
  - Actually test child SIGHUP signal
  - Profile Oslo Service processes
  - Document the threadgroup module
  - Restore correct signal handling in Python3
  - add python 3.7 unit test job
* Wed Feb  6 2019 cloud-devel@suse.de
- update to version 1.31.8
  - Stop asserting on Eventlet internals
  - Use eventlet Event for loopingcall events
  - Restore correct signal handling in Python3
  - Maintain private interface for loopingcall._ThreadingEvent
  - Fix stop of loopingcall
* Wed Nov 28 2018 cloud-devel@suse.de
- update to version 1.31.5
  - Update UPPER_CONSTRAINTS_FILE for stable/rocky
  - Add Python 3.5 jobs
  - Update .gitreview for stable/rocky
  - import zuul job settings from project-config
  - Skips signal handling on Windows
* Sat Sep  1 2018 cloud-devel@suse.de
- update to version 1.31.3
  - Update reno for stable/queens
  - Imported Translations from Zanata
  - Revert "Revert "Permit aborting loopingcall while sleeping""
  - Add release notes link to README
  - Convert oslo.service to using stestr
  - Add test dependency on requests
  - Remove unnecessary pyNN testenv
  - Fix oslo.service ProcessLauncher fails to call stop
  - Python 3: Fix non-deterministic test
  - Remove stale pip-missing-reqs tox test
  - [ThreadGroup] Don't remove timer when stop timers
  - Update links in README
  - Trivial: Update pypi url to new url
  - Fixup certificates and skip failing test
  - Remove moxstubout
  - Remove eventlet cap
  - tox.ini: Use python3.5 in py35 environment
  - set default python to python3
  - fix tox python3 overrides
  - Python 3: Fix eventlet wakeup after signal
  - Make lower-constraints job voting
  - move doc8 test to pep8 job
  - Updated from global requirements
  - add lower-constraints job
* Fri Feb 23 2018 tbechtold@suse.com
- Switch to stable/queens spec template
* Mon Jan 15 2018 cloud-devel@suse.de
- update to version 1.29.0
  - Remove -U from pip install
  - change periodic_task to catch all exceptions including BaseException
  - Update reno for stable/pike
  - Maintain shared memory after fork in Python >=3.7
  - Remove setting of version/release from releasenotes
  - Imported Translations from Zanata
  - Revert "Permit aborting loopingcall while sleeping"
  - Permit aborting loopingcall while sleeping
  - Fix bandit scan and make it voting
  - Updated from global requirements
  - Avoid tox_install.sh for constraints support
* Mon Aug  7 2017 cloud-devel@suse.de
- update to version 1.25.0
  - rearrange existing documentation to fit the new standard layout
  - Remove references to Python 3.4
  - Remove log translations
  - Fix some reST field lists in docstrings
  - Remove duplicated register_opts call
  - switch from oslosphinx to openstackdocstheme
  - Update URLs in documents according to document migration
  - Fix race condition with fast threads
  - [Fix gate]Update test requirement
  - Add min_interval to BackOffLoopingCall
  - pbr.version.VersionInfo needs package name (oslo.xyz and not oslo_xyz)
  - Update reno for stable/ocata
  - Updated from global requirements
  - Use Sphinx 1.5 warning-is-error
* Mon Feb 13 2017 cloud-devel@suse.de
- update to version 1.19.0:
  - Update .coveragerc after the removal of respective directory
  - Replace 'MagicMock' with 'Mock'
  - Delete python bytecode file
  - Imported Translations from Zanata
  - Add Constraints support
  - Add reno for release notes management
  - Stay alive on double SIGHUP
  - Show team and repo badges on README
  - Changed the home-page link
  - Enable release notes translation
  - Add FixedIntervalWithTimeoutLoopingCall
  - Updated from global requirements
* Tue Oct  4 2016 dmueller@suse.com
- switch to stable/newton
* Tue Aug 30 2016 tbechtold@suse.com
- update to version 1.16.0
  * Updated from global requirements
* Wed Aug 10 2016 tbechtold@suse.com
- update to 1.14.0:
  * Updated from global requirements
  * Fix parameters of assertEqual are misplaced
  * Imported Translations from Zanata
* Fri Jun  3 2016 tbechtold@suse.com
- use renderspec source service
- update spec from upstream
* Tue May 31 2016 slunkad@suse.com
- update to 1.11.0
  * Trivial: ignore openstack/common in flake8 exclude list
- 1.10.0
  * [Trivial] Remove executable privilege of doc/source/conf.py
- 1.9.0
  * Updated from global requirements
  * Offer mutate_config_files
  * Make _spawn_service more flexible
  * Remove direct dependency on babel
  * Updated from global requirements
  * Updated from global requirements
  * Updated from global requirements
  * Updated from global requirements
  * Fix argument type for _sd_notify() on python3
  * Use a timeutils.StopWatch for cancel timing
  * Add ability to cancel Threads and ThreadGroups
  * Exception: message need '_' function
  * Fix Heartbeats stop when time is changed
  * Updated from global requirements
* Fri Apr  1 2016 tbechtold@suse.com
- update to 1.8.0:
  * Updated from global requirements
  * Update .gitreview for stable/mitaka
* Thu Mar  3 2016 tbechtold@suse.com
- update to 1.7.0:
  * Updated from global requirements
  * Correct some help text
  * Fix typo in help text
  * wsgi: decrease the default number of greenthreads in pool
  * Updated from global requirements
  * Updated from global requirements
  * Allow the backdoor to serve from a local unix domain socket
  * Updated from global requirements
  * Use requests in TestWSGIServerWithSSL instead of raw socket client
  * Updated from global requirements
  * Updated from global requirements
  * Fix misspelling and rewrite sentence
  * Add a more useful/detailed frame dumping function
  * Updated from global requirements
  * Update translation setup
  * Fix race condition on handling signals
  * Updated from global requirements
  * Updated from global requirements
  * Updated from global requirements
  * Updated from global requirements
  * Fix artificial service.wait()
  * Graceful shutdown added to ServiceLauncher
  * Fix test execution on CentOS 7
  * Updated from global requirements
  * Fix some inconsistency in docstrings
  * Refactoring of tests/eventlet_service.py
  * Updated from global requirements
  * Remove argument ServiceLauncher.wait() method
  * fix a couple of assert issues
  * Run sslutils and wsgi tests for python3
  * Updated from global requirements
  * Updated from global requirements
  * Fix a race condition in signal handlers
  * Enable py3 mock.patch of RuntimeError
  * Delete python bytecode before every test run
  * Trival: Remove 'MANIFEST.in'
- Adjust Requires according to requirements.txt
* Wed Dec  9 2015 dmueller@suse.com
- update to 1.1.0:
  * Avoid warning when time taken is close to zero
  * Update the _i18n.py file and fix the domain value
  * Add Bandit to tox for security static analysis
  * Code refactoring of ThreadGroup::stop_timers()
  * Updated from global requirements
  * Add functionality for creating Unix domain WSGI servers
  * Use reflection.get_class_name() from oslo.utils
  * Remove Python 2.6 classifier
  * Remove openstack-common.conf
  * cleanup tox.ini
  * Change "started child" messages to DEBUG
  * Support for SSL protocol and cipher controls
  * Default value of graceful_shutdown_timeout is set to 60sec
  * Updated from global requirements
  * Logger name argument was added into wsgi.Server constructor
  * Avoid the dual-naming confusion
  * Forbid launching services with 0 or negative number of workers
* Thu Nov 19 2015 bwiedemann@suse.com
- update to 0.12.0:
  * Document graceful_shutdown_timeout config option
  * Remove py26 env from test list
  * Added config option graceful_shutdown_timeout
  * Add docstring for LoopingCallBase._start()
  * Add doc8 to py27 tox env and fix raised issues
  * Document termination of children on SIGHUP
* Mon Oct 19 2015 dmueller@suse.com
- update to 0.10.0:
  * RetryDecorator should not log warnings/errors for expected exceptions
  * Termination children on SIGHUP added
  * Fix coverage configuration and execution
  * Add register_opts function to sslutils
  * Move the common thread manipulating routine to a shared routine
  * Update log string to correctly denote what it waits on
  * Cleanup thread on thread done callback
  * Move 'history' -> release notes section
  * Add unit tests for sslutils
  * Expand README and clean up intro to sphinx docs
  * Add shields.io version/downloads links/badges into README.rst
  * add auto-generated docs for config options
  * Change ignore-errors to ignore_errors
  * Fix the home-page value in setup.cfg
  * WSGI module was corrected
  * Updated from global requirements
  * ThreadGroup's stop didn't recognise the current thread correctly
  * doing monkey_patch for unittest
* Thu Sep  3 2015 tbechtold@suse.com
- update to 0.9.0:
  * Handling corner cases in dynamic looping call
  * Change DEBUG log in loopingcall to TRACE level log
  * Updated from global requirements
  * Added wsgi functionality
- Adjust Requires according to requirements.txt
* Fri Aug 21 2015 tbechtold@suse.com
- update to 0.7.0:
  * Updated from global requirements
  * Update "Signal handling" section of usage docs
  * Use oslo_utils reflection to get 'f' callable name
  * Updated from global requirements
  * Prefix the 'safe_wrapper' function to be '_safe_wrapper'
  * Setup translations
  * Check that sighup is supported before accessing signal.SIGHUP
  * Use contextlib.closing instead of try ... finally: sock.close
  * Avoid using the global lockutils semaphore collection
  * Updated from global requirements
  * Added newline at end of file
  * Added class SignalHandler
  * Updated from global requirements
  * Activate pep8 check that _ is imported
  * Denote what happens when no exceptions are passed in
  * Allow LoopingCall to continue on exception in callee
- adjust Requires according to requirements.txt
* Wed Jul 29 2015 tbechtold@suse.com
- Unify spec file. Use fedora compatible files macros
* Tue Jul 28 2015 tbechtold@suse.com
- update to 0.5.0:
  * Updated from global requirements
  * Add oslo_debug_helper to tox.ini
  * Add usage documentation for oslo_service.service module
- update Requires according to requirements.txt
* Mon Jul 20 2015 dmueller@suse.com
- update to 0.4.0:
  * Updated from global requirements
  * Move backdoor-related tests from test_service
  * Add mock to test_requirements
  * Remove usage of mox in test_eventlet_backdoor
  * Copy RetryDecorator from oslo.vmware
  * Increase test coverage of systemd
  * Ensure we set the event and wait on the timer in the test
  * Make it easier to use the eventlet backdoor locally
  * Track created thread and disallow more than one start being active
  * Documentation on the use of the oslo-config-generator
  * Add greenlet to requirements
  * Add tox target to find missing requirements
  * Enforce H405 check
  * Enforce H301 check
  * Return timer after adding it to internal list
  * Updated from global requirements
  * Have all the looping calls share a common run loop
  * Move service abstract base class check to launch_service methods
  * Fix a typo in a comment
  * Updated from global requirements
  * Use a signal name->sigval and sigval->signal name mapping
* Wed Jun 17 2015 tbechtold@suse.com
- Initial packaging
